'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var sqlite3 = _interopDefault(require('sqlite3'));

var db = void 0;
var Promise = global.Promise;

function open(filename) {
  var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

  if (options.Promise) {
    Promise = options.Promise;
  }

  if (options.verbose) {
    sqlite3.verbose();
  }

  return new Promise(function (resolve, reject) {
    db = new sqlite3.Database(filename, function (err) {
      if (err) {
        reject(err);
      } else {
        resolve();
      }
    });
  });
}

function close() {
  return new Promise(function (resolve, reject) {
    db.close(function (err) {
      if (err) {
        reject(err);
      } else {
        resolve();
      }
    });
  });
}

function run(sql) {
  for (var _len = arguments.length, params = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    params[_key - 1] = arguments[_key];
  }

  return new Promise(function (resolve, reject) {
    db.run(sql, params || [], function cb(err) {
      if (err) {
        reject(err);
      } else {
        resolve(this);
      }
    });
  });
}

function get(sql) {
  for (var _len2 = arguments.length, params = Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
    params[_key2 - 1] = arguments[_key2];
  }

  return new Promise(function (resolve, reject) {
    db.get(sql, params || [], function (err, row) {
      if (err) {
        reject(err);
      } else {
        resolve(row);
      }
    });
  });
}

function all(sql) {
  for (var _len3 = arguments.length, params = Array(_len3 > 1 ? _len3 - 1 : 0), _key3 = 1; _key3 < _len3; _key3++) {
    params[_key3 - 1] = arguments[_key3];
  }

  return new Promise(function (resolve, reject) {
    db.all(sql, params || [], function (err, rows) {
      if (err) {
        reject(err);
      } else {
        resolve(rows);
      }
    });
  });
}

function each(sql) {
  for (var _len4 = arguments.length, params = Array(_len4 > 1 ? _len4 - 1 : 0), _key4 = 1; _key4 < _len4; _key4++) {
    params[_key4 - 1] = arguments[_key4];
  }

  var cb = params.pop();
  return new Promise(function (resolve) {
    db.each(sql, params, cb, resolve);
  });
}

function exec(sql) {
  return new Promise(function (resolve, reject) {
    db.exec(sql, function (err) {
      if (err) {
        reject(err);
      } else {
        resolve();
      }
    });
  });
}

function prepare(sql) {
  for (var _len5 = arguments.length, params = Array(_len5 > 1 ? _len5 - 1 : 0), _key5 = 1; _key5 < _len5; _key5++) {
    params[_key5 - 1] = arguments[_key5];
  }

  return new Promise(function (resolve, reject) {
    var _db;

    var statement = (_db = db).prepare.apply(_db, [sql].concat(params, [function (err) {
      if (err) {
        reject(err);
      } else {
        resolve(statement);
      }
    }]));
  });
}

/* eslint-disable object-shorthand */
var main = { get: get, open: open, close: close, run: run, all: all, each: each, exec: exec, prepare: prepare };
/* eslint-enable object-shorthand */

module.exports = main;
//# sourceMappingURL=legacy.js.map